import * as React from 'react';
import { hot } from 'react-hot-loader'
import { Route, Router } from 'react-router';

import { ThemeProvider } from 'treejs-components/styled';
import PageLayout from 'treejs-components/Layout/containers';

import ButtonPage from 'documentation/ButtonPage/components';
import CheckboxPage from 'documentation/CheckboxPage/components';
import GridPage from 'documentation/GridPage/components';
import ModalPage from 'documentation/ModalPage/components';
import RadioButtonPage from 'documentation/RadioButtonPage/components';
import SelectBoxPage from 'documentation/SelectBoxPage/components';
import TextFieldPage from 'documentation/TextFieldPage/components';
import FormsPage from 'documentation/FormsPage/components';
import WelcomePage from 'documentation/WelcomePage/components';
import { THEME } from 'documentation/WelcomePage/constants';

import { MainStyle } from '../styles/App';
import history from '../utils/history';


const App = (): React.ReactElement => {
	const leftMenuItems = [
		{ label: 'Button', href: '/button' },
		{ label: 'Checkbox', href: '/checkbox' },
		{ label: 'Grid', href: '/grid' },
		{ label: 'Modal', href: '/modal' },
		{ label: 'Radio', href: '/radioButton' },
		{ label: 'SelectBox', href: '/selectBox' },
		{ label: 'TextField', href: '/textField' },
		{ label: 'Forms', href: '/forms' },
	];

	const themeName = window.localStorage.getItem(THEME) || 'main';
	const theme = require(`treejs-components/themes/${themeName}`).default;

	return (
		<ThemeProvider theme={theme}>
			<MainStyle>
				<PageLayout leftMenuItems={leftMenuItems} history={history}>
					<Router history={history}>
						<Route path="/" exact component={WelcomePage} />
						<Route path="/button" component={ButtonPage} />
						<Route path="/checkbox" component={CheckboxPage} />
						<Route path="/grid" component={GridPage} />
						<Route path="/modal" component={ModalPage} />
						<Route path="/radioButton" component={RadioButtonPage} />
						<Route path="/selectBox" component={SelectBoxPage} />
						<Route path="/textField" component={TextFieldPage} />
						<Route path="/forms" component={FormsPage} />
					</Router>
				</PageLayout>
			</MainStyle>
		</ThemeProvider>
	);
};

export default hot(module)(App);
