import * as React from 'react';

import { Grid, GridCol, HORIZONTAL_ALIGN } from 'treejs-components/Grid';
import Field from 'treejs-forms/components/Field';
import Button from 'treejs-components/Button';

import { FIELD_TYPE } from 'treejs-forms/constants';
import { Form } from 'treejs-forms/components/Form';

import { FormErrors, IForm } from 'types/form/form';


interface FormValues {
	checkbox: boolean;
	radiobutton: string;
	selectbox: string;
	text: string;
}

class ExampleForm extends React.PureComponent implements IForm<FormValues> {
	public initialValues: FormValues = {
		text: '',
		checkbox: null,
		radiobutton: '',
		selectbox: '',
	};

	public handleSubmit = (values: FormValues): void => {
		console.info(values);
	};

	public handleValidate = (values: FormValues): FormErrors<FormValues> => {
		const errors: FormErrors<FormValues> = {};

		if (!values.text) {
			errors.text = 'Required';
		}

		if (!values.radiobutton) {
			errors.radiobutton = 'Required';
		}

		if (!values.selectbox) {
			errors.selectbox = 'Required';
		}

		return errors;
	};

	public render(): React.ReactElement {

		const radioOptions = [
			{ name: 'Field 1', code: 'field1' },
			{ name: 'Field 2', code: 'field2' }
		];

		const selectBoxOptions = [
			{ name: 'Option 1', code: 'option1' },
			{ name: 'Option 2', code: 'option2' }
		];

		return (
			<Form<FormValues>
				initialValues={this.initialValues}
				onSubmit={this.handleSubmit}
				validate={this.handleValidate}
			>
				{({ errors }): React.ReactElement => (
					<React.Fragment>
						<Grid>
							<GridCol size={3}>
								<Field
									name="text"
									title="Input"
									error={errors.text}
									component={FIELD_TYPE.TEXT_FIELD}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="checkbox"
									title="Checkbox"
									error={errors.checkbox}
									component={FIELD_TYPE.CHECKBOX}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="radiobutton"
									title="Radio Button"
									error={errors.radiobutton}
									options={radioOptions}
									component={FIELD_TYPE.RADIO_BUTTON}
								/>
							</GridCol>
							<GridCol size={3}>
								<Field
									name="selectbox"
									title="Selectbox"
									error={errors.selectbox}
									options={selectBoxOptions}
									component={FIELD_TYPE.SELECT_BOX}
								/>
							</GridCol>
						</Grid>
						<Grid horizontalAlign={HORIZONTAL_ALIGN.CENTER}>
							<GridCol size={3} >
								<Button
									type="submit"
									title="Send" />
							</GridCol>
						</Grid>
					</React.Fragment>
				)}
			</Form>
		);
	}
}

const FormsPage = (): React.ReactElement => (
	<React.Fragment>
		<h2>Forms</h2>

		<h3>Normal</h3>
		<ExampleForm />
	</React.Fragment>
);

export default FormsPage;
