import * as React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'

import { StyledCheckbox } from './style';


interface IProps {
	checked?: boolean;
	name: string;
	onBlur?: (e: React.FocusEvent<HTMLInputElement>, checked: boolean) => void;
	onChange?: (e: React.MouseEvent<HTMLInputElement>, checked: boolean) => void;
	title: string;
}

interface IState {
	checked: boolean;
}

class Checkbox extends React.PureComponent<IProps, IState> {
	public readonly state = {
		checked: this.props.checked,
	};

	private handleClick = (e: React.MouseEvent<HTMLInputElement>): void => {
		if (this.props.onChange) {
			this.props.onChange(e, !this.state.checked);
		}

		this.setState({
			checked: !this.state.checked,
		});
	};


	private handleBlur = (e: React.FocusEvent<HTMLInputElement>): void => {
		if (this.props.onBlur) {
			this.props.onBlur(e, this.state.checked);
		}
	};

	public render(): React.ReactElement {
		const {
			name,
			title,
		} = this.props;

		return (
			<StyledCheckbox>
				<label htmlFor={name}>
					<div>{title}</div>
					<FontAwesomeIcon
						size="lg"
						icon={this.state.checked ? 'check-square' : 'square'}
					/>
					<span>Check if yes</span>
				</label>
				<input
					id={name}
					name={name}
					type="checkbox"
					onClick={this.handleClick}
					onBlur={this.handleBlur}
				/>
			</StyledCheckbox>
		);
	}
}

export default Checkbox;
