import * as React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { History } from 'history';

import Modals from '../../Modal/containers/Modals';

import {
	StyledLeftMenuLabel,
	StyledLeftMenu,
	StyledLeftMenuItem,
	StyledRightSide,
	StyledTopMenu,
	StyledPageContent, StyledLeftMenuLogo, StyledTopMenuItem, StyledTopMenuItemHamburger
} from '../style';
import { IMenuItem } from '../types';


interface IProps {
	history: History;
	leftMenuItems: IMenuItem[];
}

interface IState {
	open: boolean;
}

class PageLayout extends React.PureComponent<IProps, IState> {
	public readonly state = {
		open: false,
	};

	private toggleOpenLeftMenu = () => {
		this.setState({
			open: !this.state.open,
		});
	};

	private closeLeftMenu = () => {
		if (this.state.open) {
			this.setState({
				open: false,
			});
		}
	};

	private openPage = (href: string) => () => {
		this.props.history.push(href);
		this.setState({
			open: false,
		});
	};

	public render(): React.ReactElement {
		const {
			leftMenuItems,
			children,
		} = this.props;
		const {
			open,
		} = this.state;

		return (
			<React.Fragment>
				<StyledLeftMenu open={open}>
					<StyledLeftMenuLogo>
						<FontAwesomeIcon icon="tree" />
					</StyledLeftMenuLogo>
					{
						leftMenuItems.map(
							({ label, href }, i) => (
								<StyledLeftMenuItem key={i} onClick={this.openPage(href)}>
									<StyledLeftMenuLabel open={open}>
										{label}
									</StyledLeftMenuLabel>
								</StyledLeftMenuItem>
							)
						)
					}
				</StyledLeftMenu>
				<StyledRightSide open={open}>
					<StyledTopMenu>
						<StyledTopMenuItemHamburger onClick={this.toggleOpenLeftMenu}>
							<FontAwesomeIcon icon="bars" />
						</StyledTopMenuItemHamburger>
						<StyledTopMenuItem onClick={this.openPage('/')}>
							Home
						</StyledTopMenuItem>
					</StyledTopMenu>
					<StyledPageContent open={open} onClick={this.closeLeftMenu}>
						{children}
					</StyledPageContent>
				</StyledRightSide>

				<Modals />
			</React.Fragment>
		);
	}
}

export default PageLayout;
