import * as React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'

import { StyledRadioButton, StyledRadioButtonItem } from './style';
import { IOption } from './types';


interface IProps {
	horizontal?: boolean;
	name: string;
	onBlur?: (e: React.FocusEvent<HTMLInputElement>) => void;
	onClick?: (e: React.MouseEvent<HTMLInputElement>, option: IOption) => void;
	options: IOption[];
	title?: string;
	value?: string;
}

interface IState {
	value: string;
}

class RadioButton extends React.PureComponent<IProps, IState> {
	private static defaultProps = {
		horizontal: false,
	};

	public readonly state = {
		value: this.props.value,
	};

	public componentDidUpdate(prevProps: IProps, prevState: IState): void {
		let newValue = this.state.value;

		if (prevProps.value !== this.props.value) {
			newValue = this.props.value;
		} else if (prevState.value !== this.state.value) {
			newValue = this.state.value;
		} else {
			return;
		}

		this.setState({
			value: newValue,
		});
	}

	private handleClick = (option: IOption): any => (e: React.MouseEvent<HTMLInputElement>): void => {
		if (this.props.onClick) {
			this.props.onClick(e, option);
		}

		this.setState({
			value: option.code,
		})
	};

	private handleBlur = (e: React.FocusEvent<HTMLInputElement>): void => {
		if (this.props.onBlur) {
			this.props.onBlur(e);
		}
	};

	public render(): React.ReactElement {
		const {
			title,
			options,
			horizontal,
		} = this.props;

		const optionElements = options.map(
			({ code, name }): React.ReactElement => (
				<StyledRadioButtonItem horizontal={horizontal} key={code}>
					<input
						id={`${this.props.name}_${code}`}
						name={name}
						type="radio"
						onClick={this.handleClick({ code, name })}
						onBlur={this.handleBlur}
					/>
					<label htmlFor={`${this.props.name}_${code}`}>
						<FontAwesomeIcon
							size="lg"
							icon={
								this.state.value === code ? 'dot-circle' : 'circle'
							}
						/>
						<span>{name}</span>
					</label>
				</StyledRadioButtonItem>
			)
		);

		return (
			<StyledRadioButton>
				<div>{title}</div>
				{optionElements}
			</StyledRadioButton>
		);
	}
}

export default RadioButton;
