import * as React from 'react';
import { Field as FormikField } from 'formik';

import { IOption } from 'treejs-components/RadioButton/types';

import { FIELD_TYPE } from '../constants';

import TextField from './fields/TextField';
import CheckboxField from './fields/CheckboxField';
import RadioButtonField from './fields/RadioButtonField';
import SelectBoxField from './fields/SelectBoxField';


interface IProps {
	component: FIELD_TYPE;
	disabled?: boolean;
	error?: string;
	name: string;
	options?: IOption[];
	title: string;
}

export class Field extends React.Component<IProps> {
	public static defaultProps: IProps = {
		component: FIELD_TYPE.TEXT_FIELD,
		name: 'field',
		title: 'Field',
	};

	public render(): React.ReactElement {
		const {
			component,
			...other
		} = this.props;

		switch(component) {
			case FIELD_TYPE.TEXT_FIELD:
				return (
					<FormikField component={TextField} {...other} />
				);
			case FIELD_TYPE.CHECKBOX:
				return (
					<FormikField component={CheckboxField} {...other} />
				);
			case FIELD_TYPE.RADIO_BUTTON:
				return (
					<FormikField component={RadioButtonField} {...other} />
				);
			case FIELD_TYPE.SELECT_BOX:
				return (
					<FormikField component={SelectBoxField} {...other} />
				);
		}

		return null;
	}
}

export default Field;
