import * as React from 'react';
import { FieldProps } from 'formik';

import CheckBoxComponent from 'treejs-components/Checkbox';

import { StyledCheckboxErrorMessageContainer } from '../../style';


interface IProps extends FieldProps {
	error: string;
	title: string;
	value: boolean;
}

const CheckboxField = (props: IProps): React.ReactElement => {
	const {
		field: {
			name,
			value,
			onChange,
			onBlur,
		},
		title,
		error,
	} = props;

	const handleClick = (e: React.MouseEvent): void => {
		onChange(e);
	};
	const handleBlur = (e: React.FocusEvent): void => {
		onBlur(e);
	};

	return (
		<div>
			<CheckBoxComponent
				name={name}
				title={title}
				checked={value}
				onChange={handleClick}
				onBlur={handleBlur}
			/>
			<StyledCheckboxErrorMessageContainer>{error}</StyledCheckboxErrorMessageContainer>
		</div>
	);
};

export default CheckboxField;
