import * as React from 'react';
import { FieldProps } from 'formik';

import RadioButtonComponent from 'treejs-components/RadioButton';
import { IOption } from 'treejs-components/RadioButton/types';

import { StyledCheckboxErrorMessageContainer } from '../../style';


interface IProps extends FieldProps {
	error: string;
	options: IOption[];
	title: string;
	value: boolean;
}

const RadioButtonField = (props: IProps): React.ReactElement => {
	const {
		field: {
			name,
			value,
			onBlur,
		},
		form: {
			setFieldValue,
		},
		title,
		error,
		options,
	} = props;

	const handleClick = (e: React.MouseEvent, option: IOption): void => {
		setFieldValue(name, option.code);
	};

	const handleBlur = (e: React.FocusEvent<HTMLInputElement>): void => {
		onBlur(e);
	};

	return (
		<div>
			<RadioButtonComponent
				horizontal
				name={name}
				title={title}
				value={value}
				options={options}
				onClick={handleClick}
				onBlur={handleBlur}
			/>
			<StyledCheckboxErrorMessageContainer>{error}</StyledCheckboxErrorMessageContainer>
		</div>
	);
};

export default RadioButtonField;
