import * as React from 'react';
import { FieldProps } from 'formik';

import { STATUS } from 'types/common';

import SelectBoxComponent from 'treejs-components/SelectBox/containers';
import { IOption } from 'treejs-components/SelectBox/types';
import { isNilOrEmpty } from 'treejs-utils';

import { StyledTextFieldErrorMessageContainer } from '../../style';


interface IProps extends FieldProps {
	error: string;
	options: IOption[];
	title: string;
	value: string;
}

const SelectBox = (props: IProps): React.ReactElement => {
	const {
		field: {
			name,
			value,
			onBlur,
		},
		form: {
			setFieldValue,
		},
		title,
		error,
		options,
	} = props;

	const handleChange = (option: IOption): void => {
		if (isNilOrEmpty(option)) {
			setFieldValue(name, undefined);
		} else {
			setFieldValue(name, option.code);
		}
	};

	const handleBlur = (e: React.FocusEvent<HTMLInputElement>): void => {
		onBlur(e);
	};

	const status = !isNilOrEmpty(error) && STATUS.error;

	return (
		<div>
			<SelectBoxComponent
				name={name}
				title={title}
				value={value}
				options={options}
				onChange={handleChange}
				onBlur={handleBlur}
				status={status}
			/>
			<StyledTextFieldErrorMessageContainer>{error}</StyledTextFieldErrorMessageContainer>
		</div>
	);
};

export default SelectBox;
