import * as React from 'react';
import { FieldProps } from 'formik';

import TextFieldComponent from 'treejs-components/TextField';
import { isNilOrEmpty } from 'treejs-utils';
import { STATUS } from 'types/common';

import { StyledTextFieldErrorMessageContainer } from '../../style';


interface IProps extends FieldProps {
	disabled: boolean;
	error: string;
	title: string;
	value: string;
}

const TextField = (props: IProps): React.ReactElement => {
	const {
		field: {
			name,
			value,
			onChange,
			onBlur,
		},
		title,
		error,
		disabled,
	} = props;

	const handleChange = (e: React.ChangeEvent): void => {
		onChange(e);
	};

	const handleBlur = (e: React.FocusEvent): void => {
		onBlur(e);
	};

	const status = !isNilOrEmpty(error) && STATUS.error;

	return (
		<div>
			<TextFieldComponent
				name={name}
				title={title}
				value={value}
				onChange={handleChange}
				onBlur={handleBlur}
				status={status}
				disabled={disabled}
			/>
			{!disabled && <StyledTextFieldErrorMessageContainer>{error}</StyledTextFieldErrorMessageContainer>}
		</div>
	);
};

export default TextField;
